#ifndef JX_UART_SEND_H_
#define JX_UART_SEND_H_

#ifdef __cplusplus
extern "C" {
#endif

// 串口发送消息最大长度
#define UART_SEND_MAX      32
#define UART_MSG_HEAD_LEN_UART1_RX  2
#define UART_MSG_FOOT_LEN_UART1_RX  2

#define UART_MSG_HEAD_LEN_UART0_RX  2
#define UART_MSG_FOOT_LEN_UART0_RX  2

// 串口发送消息号
#define U_MSG_A8      1
#define U_MSG_A9      2
#define U_MSG_A10      3
#define U_MSG_A11      4
#define U_MSG_A12      5
#define U_MSG_A13      6
#define U_MSG_A14      7
#define U_MSG_A15      8

// 串口消息参数类型
typedef union {
  double d_double;
  int d_int;
  unsigned char d_ucs[8];
  char d_char;
  unsigned char d_uchar;
  unsigned long d_long;
  short d_short;
  float d_float;
}uart_param_t;

// 十六位整数转32位整数
void _int16_to_int32(uart_param_t* param) {
  if (sizeof(int) >= 4)
    return;
  unsigned long value = param->d_long;
  unsigned long sign = (value >> 15) & 1;
  unsigned long v = value;
  if (sign)
    v = 0xFFFF0000 | value;
  uart_param_t p;
  p.d_long = v;
  param->d_ucs[0] = p.d_ucs[0];
  param->d_ucs[1] = p.d_ucs[1];
  param->d_ucs[2] = p.d_ucs[2];
  param->d_ucs[3] = p.d_ucs[3];
}

// 浮点数转双精度 
void _float_to_double(uart_param_t* param) {
  if (sizeof(int) >= 4)
    return;
  unsigned long value = param->d_long;
  unsigned long sign = value >> 31;
  unsigned long M = value & 0x007FFFFF;
  unsigned long e =  ((value >> 23 ) & 0xFF) - 127 + 1023;
  uart_param_t p0, p1;  
  p1.d_long = ((sign & 1) << 31) | ((e & 0x7FF) << 20) | (M >> 3);
  p0.d_long = (M & 0x7) << 29;
  param->d_ucs[0] = p0.d_ucs[0];
  param->d_ucs[1] = p0.d_ucs[1];
  param->d_ucs[2] = p0.d_ucs[2];
  param->d_ucs[3] = p0.d_ucs[3];
  param->d_ucs[4] = p1.d_ucs[0];
  param->d_ucs[5] = p1.d_ucs[1];
  param->d_ucs[6] = p1.d_ucs[2];
  param->d_ucs[7] = p1.d_ucs[3];
}

// action: A8
void _uart_A8();

// action: A9
void _uart_A9();

// action: A10
void _uart_A10();

// action: A11
void _uart_A11();

// action: A12
void _uart_A12(unsigned char U1_Hum);

// action: A13
void _uart_A13(unsigned char U0_Hum);

// action: A14
void _uart_A14(unsigned char U1_ZHENG, unsigned char U1_XIAO);

// action: A15
void _uart_A15(unsigned char U0_ZHENG, unsigned char U0_XIAO);

#ifdef __cplusplus
}
#endif

#endif /*JX_UART_SEND_H_*/

